@@ -33,14 +33,26 @@ class MySpider(Spider):
         yield Request(...)
 
 
-Some times you need to initialize a session for a specific request generated in the spider code. In that case,
+Some times you need to initialize a session for a single request generated in a spider method. In that case,
 you can use init_request() method:
 
     def parse(self, response):
+        ...
+        yield Request(...)
         ...
         yield crawlera_session.init_request(Request(...))
 
 
+If on the contrary, you want to send a normal (not session) request from a callback that was decorated with follow_session,
+you can use the no_crawlera_session meta tag:
+
+    @crawlera_session.follow_session
+    def parse(self, response):
+        ...
+        yield Request(...)
+        ...
+        yield Request(..., meta={'no_crawlera_session': True})
+
 """
 import uuid
 import logging
@@ -50,16 +62,17 @@ from scrapy import Request
 from scrapy.downloadermiddlewares.redirect import RedirectMiddleware
 
 
-__version__ = '1.0'
+__version__ = '1.0.2'
 
-logger = logging.getLogger()
+logger = logging.getLogger(__name__)
 
 
 class RequestSession(object):
-    def __init__(self, crawlera_session=True, x_crawlera_cookies='disable', x_crawlera_profile=None):
+    def __init__(self, crawlera_session=True, x_crawlera_cookies='disable', x_crawlera_profile=None, x_crawlera_wait=None):
         self.crawlera_session = crawlera_session
         self.x_crawlera_cookies = x_crawlera_cookies
         self.x_crawlera_profile = x_crawlera_profile
+        self.x_crawlera_wait = x_crawlera_wait
 
     def follow_session(self, wrapped):
         def _wrapper(spider, response):
@@ -92,6 +105,8 @@ class RequestSession(object):
             request.headers['X-Crawlera-Cookies'] = self.x_crawlera_cookies
         if self.x_crawlera_profile is not None:
             request.headers['X-Crawlera-Profile'] = self.x_crawlera_profile
+        if self.x_crawlera_wait is not None:
+            request.headers['X-Crawlera-Wait'] = self.x_crawlera_wait
 
     def init_request(self, request):
         if 'cookiejar' not in request.meta:
